@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: HUnit
-version: 1.2.5.1
-id: HUnit-1.2.5.1-04fafbcfa793ac20134c5b9972485d17
+version: 1.2.5.2
+id: HUnit-1.2.5.2-6e02ecc15e3cc5ab8ef10df50d05a1a9
 
 license: BSD3
 copyright:
@@ -20,20 +20,20 @@ exposed-modules: Test.HUnit.Base Test.HUnit.Lang
                  Test.HUnit.Terminal Test.HUnit.Text Test.HUnit
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/HUnit-1.2.5.1
-library-dirs: /usr/local/lib/ghc/HUnit-1.2.5.1
-hs-libraries: HSHUnit-1.2.5.1
+import-dirs: /usr/local/lib/ghc/HUnit-1.2.5.2
+library-dirs: /usr/local/lib/ghc/HUnit-1.2.5.2
+hs-libraries: HSHUnit-1.2.5.2
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         deepseq-1.3.0.0-c8a9e8b538aecb7581533b9c1d19faed
+depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         deepseq-1.3.0.1-5cc4cd89bdc2e8f6db1833d95ec36926
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-HUnit-1.2.5.1/html/HUnit.haddock
-haddock-html: /usr/local/share/doc/hs-HUnit-1.2.5.1/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-HUnit-1.2.5.2/html/HUnit.haddock
+haddock-html: /usr/local/share/doc/hs-HUnit-1.2.5.2/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
